==> haskell-data-accessor-transformers-0.2.1.7-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-accessor-transformers
version:              0.2.1.7
visibility:           public
id:                   data-accessor-transformers-0.2.1.7-CXaW69V5DI1FQmwHSnYsJm
key:                  data-accessor-transformers-0.2.1.7-CXaW69V5DI1FQmwHSnYsJm
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  0e49ccb7baaf41e0101c0158a749615c
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/data-accessor-transformers-0.2.1.7

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/data-accessor-transformers-0.2.1.7

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/data-accessor-transformers-0.2.1.7

hs-libraries:         HSdata-accessor-transformers-0.2.1.7-CXaW69V5DI1FQmwHSnYsJm
depends:
    base-4.15.0.0 data-accessor-0.2.3-IN9WkeNzZKDCoB2nA1bq00
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-transformers-0.2.1.7-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-accessor-transformers
version:              0.2.1.7
visibility:           public
id:                   data-accessor-transformers-0.2.1.7-DUy92fZnReO83spsWBSSqW
key:                  data-accessor-transformers-0.2.1.7-DUy92fZnReO83spsWBSSqW
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  939a08403426e67841d48f713ad65569
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/data-accessor-transformers-0.2.1.7

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/data-accessor-transformers-0.2.1.7

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/data-accessor-transformers-0.2.1.7

hs-libraries:         HSdata-accessor-transformers-0.2.1.7-DUy92fZnReO83spsWBSSqW
depends:
    base-4.15.1.0 data-accessor-0.2.3-DagNde82Qt1I2jIIA5ve9G
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
